ansible-galaxy-local-deps
=========
![Build Status](https://github.com/andrewrothstein/ansible-galaxy-local-deps/actions/workflows/build.yml/badge.svg)

A bunch of python scripts supporting ansible role testing in CI
